@@ -68,36 +68,30 @@ class Project:
     @classmethod
     def from_files(
         cls,
-        pipfile_path: str = None,
-        pipfile_lock_path: str = None,
+        pipfile_path: Optional[str] = None,
+        pipfile_lock_path: Optional[str] = None,
         *,
-        runtime_environment: RuntimeEnvironment = None,
+        runtime_environment: Optional[RuntimeEnvironment] = None,
         without_pipfile_lock: bool = False,
     ):
         """Create project from Pipfile and Pipfile.lock files."""
         try:
-            with open(pipfile_path or "Pipfile", "r") as pipfile_file:
-                pipfile_str = pipfile_file.read()
+            pipfile = Pipfile.from_file(pipfile_path)
         except Exception as exc:
             raise FileLoadError(
                 f"Failed to load Pipfile (path: {os.getcwd() if not pipfile_path else pipfile_path}: {str(exc)}"
             ) from exc
 
-        pipfile = Pipfile.from_string(pipfile_str)
-
         pipfile_lock = None
         if not without_pipfile_lock:
             try:
-                with open(pipfile_lock_path or "Pipfile.lock", "r") as pipfile_lock_file:
-                    pipfile_lock_str = pipfile_lock_file.read()
+                pipfile_lock = PipfileLock.from_file(pipfile_lock_path, pipfile=pipfile)
             except Exception as exc:
                 raise FileLoadError(
                     f"Failed to load Pipfile.lock "
                     f"(path: {os.getcwd() if not pipfile_lock_path else pipfile_lock_path}: {str(exc)}"
                 ) from exc
 
-            pipfile_lock = PipfileLock.from_string(pipfile_lock_str, pipfile=pipfile)
-
         return cls(
             pipfile,
             pipfile_lock,
@@ -106,14 +100,23 @@ class Project:
 
     @classmethod
     def from_dict(
-        cls, pipfile: Dict[str, Any], pipfile_lock: Dict[str, Any], runtime_environment: RuntimeEnvironment = None,
+        cls,
+        pipfile: Dict[str, Any],
+        pipfile_lock: Dict[str, Any],
+        runtime_environment: Optional[RuntimeEnvironment] = None,
     ) -> "Project":
         """Construct project out of a dict representation."""
         pip = Pipfile.from_dict(pipfile)
+        if runtime_environment:
+            return cls(
+                pipfile=pip,
+                pipfile_lock=PipfileLock.from_dict(pipfile_lock, pipfile=pip),
+                runtime_environment=runtime_environment,
+            )
+
         return cls(
             pipfile=pip,
             pipfile_lock=PipfileLock.from_dict(pipfile_lock, pipfile=pip),
-            runtime_environment=runtime_environment,
         )
 
     @classmethod
@@ -134,11 +137,16 @@ class Project:
         )
 
     def to_files(
-        self, pipfile_path: str = None, pipfile_lock_path: str = None, without_pipfile_lock: bool = False
+        self,
+        pipfile_path: str = None,
+        pipfile_lock_path: str = None,
+        *,
+        without_pipfile_lock: bool = False,
+        keep_thoth_section: bool = False,
     ) -> None:
         """Write the current state of project into Pipfile and Pipfile.lock files."""
         with open(pipfile_path or "Pipfile", "w") as pipfile_file:
-            pipfile_file.write(self.pipfile.to_string())
+            pipfile_file.write(self.pipfile.to_string(keep_thoth_section=keep_thoth_section))
 
         if not without_pipfile_lock:
             with open(pipfile_lock_path or "Pipfile.lock", "w") as pipfile_lock_file:
@@ -195,8 +203,6 @@ class Project:
                 sources, package_versions = parse_requirements(requirements_path)
                 if requirements_lock_path is not None:
                     sources_lock, package_versions_lock = parse_requirements(requirements_lock_path)
-                elif os.path.exists("requirements.txt"):
-                    sources_lock, package_versions_lock = parse_requirements("requirements.txt")
         else:
             requirements_lock_path = requirements_lock_path or "requirements.txt"
             sources, package_versions = parse_requirements(requirements_path)
@@ -233,7 +239,10 @@ class Project:
         if package_versions_lock:
             pipfile_lock = PipfileLock.from_package_versions(pipfile=pipfile, packages=package_versions_lock, meta=meta)
 
-        return cls(pipfile, pipfile_lock, runtime_environment=runtime_environment)
+        if runtime_environment:
+            return cls(pipfile, pipfile_lock, runtime_environment=runtime_environment)
+
+        return cls(pipfile, pipfile_lock)
 
     @classmethod
     def from_package_versions(
@@ -297,7 +306,7 @@ class Project:
             "runtime_environment": self.runtime_environment.to_dict(),
         }
 
-    def get_configuration_check_report(self) -> Optional[Tuple[dict, List[dict]]]:
+    def get_configuration_check_report(self) -> Optional[Tuple[Optional[dict], List[dict]]]:
         """Get a report on project configuration for the given runtime environment."""
         result = []
         changes_in_config = False
